@@ -42,9 +42,10 @@ def _fix_references(s):
 
 
 class RstFormatter(object):
-    def __init__(self, filename, output):
+    def __init__(self, filename, output, title=None):
         self.parser = gir2rst.parser.GirParser(filename)
         self.output = output
+        self.title = title
         self.wrapper = textwrap.TextWrapper(initial_indent='    ',
                 subsequent_indent='    ')
         self.ns_core = string.Template('%s$tag' %
@@ -53,9 +54,12 @@ class RstFormatter(object):
 
     def write_rst(self):
         namespace = self.parser.get_namespace()
-        title = "%s %s API reference" % (namespace.attrib['name'],
-                namespace.attrib['version'])
-        self.output.write(_rst_h1(title))
+        if self.title:
+            self.output.write(_rst_h1(self.title % namespace.attrib))
+        else:
+            title = "%s %s API reference" % (namespace.attrib['name'],
+                    namespace.attrib['version'])
+            self.output.write(_rst_h1(title))
 
         for class_element in self.parser.get_classes():
             self.output_class(class_element)
@@ -96,7 +100,8 @@ class RstFormatter(object):
         """Output parameter description like ':param foo: foo description'."""
         params = self.parser.get_parameters(func_element)
         param_descriptions = ["    :param %s: %s\n" % (p.attrib['name'],
-            _fix_references(self.parser.get_element_doc(p))) for p in params]
+            _fix_references(self.parser.get_element_doc(p))) for p in params if
+            'name' in p.attrib]
 
         if params:
             self.output.write('\n')
@@ -108,7 +113,8 @@ class RstFormatter(object):
         """Output the return value like ':returns: return value description'.
         """
         rval = self.parser.get_return_value(meth_element)
-        if self.parser.get_type(rval).attrib['name'] != 'none':
+        rval_type = self.parser.get_type(rval)
+        if 'name' in rval_type.attrib and rval_type.attrib['name'] != 'none':
             doc = self.parser.get_element_doc(rval)
             self.output.write('\n    :returns: %s\n' % _fix_references(doc))
         self.output.write('\n\n')
@@ -125,8 +131,8 @@ class RstFormatter(object):
 
 
 class RstCFormatter(RstFormatter):
-    def __init__(self, filename, output):
-        super(RstCFormatter, self).__init__(filename, output)
+    def __init__(self, filename, output, title=None):
+        super(RstCFormatter, self).__init__(filename, output, title)
 
     def output_class(self, class_element):
         name = self.parser.get_c_type_attrib(class_element)
